@@ -5,10 +5,11 @@
 
 """Module ``pylint_gitlab``."""
 
-from pylint_gitlab.reporter import GitlabCodeClimateReporter, GitlabPagesHtmlReporter
+from pylint_gitlab.reporter import GitlabCodeClimateReporter, GitlabCodeClimateReporterNoHash, GitlabPagesHtmlReporter
 
 
 def register(linter):
     """Register the reporter classes with the linter."""
     linter.register_reporter(GitlabCodeClimateReporter)
+    linter.register_reporter(GitlabCodeClimateReporterNoHash)
     linter.register_reporter(GitlabPagesHtmlReporter)
