@@ -97,3 +97,48 @@ def test_gitlab_code_climate_reporter(use_load_plugins):
     }]
     report_result = json.loads(output.getvalue())
     assert report_result == expected_result
+
+
+@pytest.mark.parametrize("use_load_plugins", [False, True])
+def test_gitlab_code_climate_reporter_no_hash(use_load_plugins):
+    """Tests for ``pylint_gitlab.reporter.GitlabCodeClimateReporterNoHash()``."""
+
+    if use_load_plugins:
+        plugins = ["pylint_gitlab"]
+        reporter = "gitlab-codeclimate-nohash"
+    else:
+        plugins = []
+        reporter = "pylint_gitlab.GitlabCodeClimateReporterNoHash"
+
+    output = StringIO()
+    linter = PyLinter()
+
+    linter.load_plugin_modules(plugins)
+    linter.set_option("output-format", reporter)
+    linter.set_option("persistent", False)
+    linter.load_default_plugins()
+
+    reporter = linter.reporter
+    reporter.set_output(output)
+
+    linter.open()
+
+    linter.set_current_module("0123")
+    linter.add_message("line-too-long", line=1, args=(1, 2))
+
+    # we call this method because we didn't actually run the checkers
+    reporter.display_messages(None)
+
+    expected_result = [{
+        "description": "C0301: Line too long (1/2)",
+        "severity": "minor",
+        "location": {
+            "path": "0123",
+            "lines": {
+                "begin": 1,
+            }
+        },
+        "fingerprint": "0123:1:C0301"
+    }]
+    report_result = json.loads(output.getvalue())
+    assert report_result == expected_result
